@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # coding: utf-8
 # vim: set ts=4 sw=4 expandtab sts=4:
 # Copyright (c) 2011-2014 Christian Geier & contributors
@@ -23,18 +22,14 @@
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 import calendar
-from datetime import date
-from datetime import time
-from datetime import datetime
+from datetime import date, datetime, time, timedelta
 
 import urwid
 
 from .. import aux
-from ..event import Event
-from ..status import OK, NEW, CHANGED, NEWNOTSAVED, DELETED, NEWDELETE, CALCHANGED
 
-
-from base import Pane, Window, CColumns, CPile, CSimpleFocusListWalker
+from .base import Pane, Window, CColumns, CPile, CSimpleFocusListWalker
+from .startendeditor import StartEndEditor
 
 
 class DateConversionError(Exception):
@@ -42,6 +37,7 @@ class DateConversionError(Exception):
 
 
 class AccountList(urwid.WidgetWrap):
+
     """used as the popup in the AccountChooser popup"""
     signals = ['close']
 
@@ -63,9 +59,11 @@ class AccountList(urwid.WidgetWrap):
 
 
 class AccountChooser(urwid.PopUpLauncher):
+
     """show current account and lets user choose another account
 
     does NOT handle the actual moving of an event to another account"""
+
     def __init__(self, active_account, accounts):
         self.active_account = active_account
         self.original_account = active_account
@@ -108,6 +106,7 @@ class AccountChooser(urwid.PopUpLauncher):
 
 
 class Date(urwid.Text):
+
     """used in the main calendar for dates (a number)"""
 
     def __init__(self, date, view):
@@ -133,6 +132,7 @@ class Date(urwid.Text):
 
 
 class DateCColumns(CColumns):
+
     """container for one week worth of dates
     which are horizontally aligned
 
@@ -141,6 +141,7 @@ class DateCColumns(CColumns):
     focus can only move away by pressing 'TAB',
     calls 'view.show_date' on every focus change (see below for details)
     """
+
     def __init__(self, widget_list, view=None, **kwargs):
         self.view = view
         super(DateCColumns, self).__init__(widget_list, **kwargs)
@@ -153,7 +154,8 @@ class DateCColumns(CColumns):
         # since first Column is month name, focus should only be 0 during
         # construction
         if not self.contents.focus == 0:
-            self.view.show_date(self.contents[position][0].original_widget.date)
+            self.view.show_date(
+                self.contents[position][0].original_widget.date)
 
     focus_position = property(CColumns._get_focus_position,
                               _set_focus_position, doc="""
@@ -196,6 +198,7 @@ def calendar_walker(view, firstweekday=0):
 
 
 class CalendarWalker(urwid.SimpleFocusListWalker):
+
     def __init__(self, view, firstweekday=0):
         self.firstweekday = firstweekday
         self.view = view
@@ -243,8 +246,9 @@ class CalendarWalker(urwid.SimpleFocusListWalker):
 
     def _construct_week(self, week):
         """
-        constructs a CColumns week from a week of datetime.date objects. Also prepends the month name
-        if the first day of the month is included in that week.
+        constructs a CColumns week from a week of datetime.date objects. Also
+        prepends the month name if the first day of the month is included in
+        that week.
 
         :param week: list of datetime.date objects
         :returns: the week as an CColumns object and True or False depending on
@@ -281,20 +285,23 @@ class CalendarWalker(urwid.SimpleFocusListWalker):
         :type year: int
         :param month: the number of the month to be constructed
         :type month: int (1-12)
-        :param clean_first_row: makes sure that the first element returned is completely in `month` and
-                                not partly in the one before (which might lead to that line occurring
+        :param clean_first_row: makes sure that the first element returned is
+                                completely in `month` and not partly in the one
+                                before (which might lead to that line occurring
                                 twice
         :type clean_first_row: bool
-        :param clean_last_row: makes sure that the last element returned is completely in `month` and
-                                not partly in the one after (which might lead to that line occurring
-                                twice
+        :param clean_last_row: makes sure that the last element returned is
+                               completely in `month` and not partly in the one
+                               after (which might lead to that line occurring
+                               twice
         :type clean_last_row: bool
         :returns: list of DateCColumns and the number of the list element which
                   contains today (or None if it isn't in there)
         :rtype: tuple(list(dateCColumns, int or None))
         """
 
-        plain_weeks = calendar.Calendar(self.firstweekday).monthdatescalendar(year, month)
+        plain_weeks = calendar.Calendar(
+            self.firstweekday).monthdatescalendar(year, month)
         weeks = list()
         focus_item = None
         for number, week in enumerate(plain_weeks):
@@ -302,17 +309,20 @@ class CalendarWalker(urwid.SimpleFocusListWalker):
             if contains_today:
                 focus_item = number
             weeks.append(week)
-        if clean_first_row and weeks[0][1].date.month != weeks[0][7].date.month:
+        if clean_first_row and \
+           weeks[0][1].date.month != weeks[0][7].date.month:
             if focus_item is not None:
                 focus_item = focus_item - 1
             return weeks[1:], focus_item
-        elif clean_last_row and weeks[-1][1].date.month != weeks[-1][7].date.month:
+        elif clean_last_row and \
+                weeks[-1][1].date.month != weeks[-1][7].date.month:
             return weeks[:-1], focus_item
         else:
             return weeks, focus_item
 
 
 class U_Event(urwid.Text):
+
     def __init__(self, event, this_date=None, conf=None,
                  eventcolumn=None):
         """
@@ -321,36 +331,36 @@ class U_Event(urwid.Text):
         :param event: the encapsulated event
         :type event: khal.event.Event
         """
-
         self.event = event
         self.this_date = this_date
         self.conf = conf
         self.eventcolumn = eventcolumn
         self.view = False
         super(U_Event, self).__init__(self.event.compact(self.this_date))
+        self.set_title()
 
     @classmethod
     def selectable(cls):
         return True
 
+    @property
+    def uid(self):
+        return self.event.account + '\n' + str(self.event.href)
+
+    def set_title(self, mark=''):
+        if self.uid in self.eventcolumn.deleted:
+            mark = 'D'
+        self.set_text(mark + ' ' + self.event.compact(self.this_date))
+
     def toggle_delete(self):
-        if self.event.readonly is False:
-            # TODO update for NEWNOTSAVED
-            if self.event.status == OK:
-                toggle = DELETED
-            elif self.event.status == DELETED:
-                toggle = OK
-            elif self.event.status == NEW:
-                toggle = NEWDELETE
-            elif self.event.status == NEWDELETE:
-                toggle = NEW
-            else:
-                toggle = DELETED
-            self.event.status = toggle
-            self.set_text(self.event.compact(self.this_date))
-            self.eventcolumn.collection.mark(toggle, self.event)
+        if self.event.readonly is True:
+            self.set_title('RO')
+            return
+        if self.uid in self.eventcolumn.deleted:
+            self.eventcolumn.deleted.remove(self.uid)
         else:
-            self.set_text('RO' + self.event.compact(self.this_date))
+            self.eventcolumn.deleted.append(self.uid)
+        self.set_title()
 
     def keypress(self, _, key):
         if key == 'enter' and self.view is False:
@@ -366,7 +376,9 @@ class U_Event(urwid.Text):
 
 
 class EventList(urwid.WidgetWrap):
+
     """list of events"""
+
     def __init__(self, conf=None, collection=None, eventcolumn=None):
         self.conf = conf
         self.collection = collection
@@ -381,7 +393,7 @@ class EventList(urwid.WidgetWrap):
         end = datetime.combine(this_date, time.max)
 
         date_text = urwid.Text(
-            this_date.strftime(self.conf.default.longdateformat))
+            this_date.strftime(self.conf.locale.longdateformat))
         event_column = list()
         all_day_events = self.collection.get_allday_by_time_range(this_date)
         events = self.collection.get_datetime_by_time_range(start, end)
@@ -401,7 +413,8 @@ class EventList(urwid.WidgetWrap):
                                       this_date=this_date,
                                       eventcolumn=self.eventcolumn),
                               event.color, 'reveal focus'))
-        event_list = [urwid.AttrMap(event, None, 'reveal focus') for event in event_column]
+        event_list = [urwid.AttrMap(event, None, 'reveal focus')
+                      for event in event_column]
         event_count = len(event_list)
         if not event_list:
             event_list = [urwid.Text('no scheduled events')]
@@ -412,10 +425,13 @@ class EventList(urwid.WidgetWrap):
 
 
 class EventColumn(urwid.WidgetWrap):
+
     """contains the eventlist as well as the event viewer/editor"""
-    def __init__(self, conf=None, collection=None):
+
+    def __init__(self, conf, collection, deleted):
         self.conf = conf
         self.collection = collection
+        self.deleted = deleted
         self.divider = urwid.Divider('-')
         self.editor = False
         self.date = None
@@ -426,7 +442,8 @@ class EventColumn(urwid.WidgetWrap):
         """
         self.date = date
         # TODO make this switch from pile to columns depending on terminal size
-        events = EventList(conf=self.conf, collection=self.collection, eventcolumn=self)
+        events = EventList(
+            conf=self.conf, collection=self.collection, eventcolumn=self)
         self.eventcount = events.update(date)
         self.container = CPile([events])
         self._w = self.container
@@ -441,7 +458,6 @@ class EventColumn(urwid.WidgetWrap):
         self.destroy()
         self.container.contents.append((self.divider,
                                         ('pack', None)))
-                                        #self.container.options()))
         self.container.contents.append(
             (EventDisplay(self.conf, event, collection=self.collection),
              self.container.options()))
@@ -454,12 +470,13 @@ class EventColumn(urwid.WidgetWrap):
         """
         self.destroy()
         self.editor = True
-        #self.container.contents.append((self.divider,
-                                        #self.container.options()))
+        # self.container.contents.append((self.divider,
+        #                                 self.container.options()))
         self.container.contents.append((self.divider,
                                         ('pack', None)))
         self.container.contents.append(
-            (EventEditor(self.conf, event, collection=self.collection, cancel=self.destroy),
+            (EventEditor(self.conf, event, collection=self.collection,
+                         cancel=self.destroy),
              self.container.options()))
         self.container.set_focus(2)
 
@@ -467,7 +484,7 @@ class EventColumn(urwid.WidgetWrap):
         """
         if an EventViewer or EventEditor is displayed, remove it
         """
-        if refresh and not self.date is None:
+        if refresh and self.date is not None:
             self.update(self.date)
         self.editor = False
         if (len(self.container.contents) > 2 and
@@ -482,9 +499,15 @@ class EventColumn(urwid.WidgetWrap):
         :type date: datetime.date
         """
         event = aux.new_event(dtstart=date,
-                              timezone=self.conf.default.default_timezone)
-        event = Event(ical=event.to_ical(), status=NEWNOTSAVED,
-                      account=list(self.conf.sync.accounts)[-1])
+                              timezone=self.conf.locale.default_timezone)
+
+        # TODO proper default cal
+        event = self.collection.new_event(
+            event.to_ical(),
+            self.collection.default_calendar_name,
+            local_tz=self.conf.locale.local_timezone,
+            default_tz=self.conf.locale.default_timezone)
+
         self.edit(event)
         self.eventcount += 1
 
@@ -493,6 +516,7 @@ class EventColumn(urwid.WidgetWrap):
 
 
 class RecursionEditor(urwid.WidgetWrap):
+
     def __init__(self, rrule):
         # TODO: actually implement the Recursion Editor
         self.recursive = False if rrule is None else True
@@ -508,179 +532,12 @@ class RecursionEditor(urwid.WidgetWrap):
                                           self.columns.options()))
 
 
-class StartEndEditor(urwid.WidgetWrap):
-    """
-    editing start and nd times of the event
-
-    we cannot change timezones ATM  # TODO
-    pop up on strings not matching timeformat # TODO
-    """
-
-    def __init__(self, start, end, conf):
-        self.conf = conf
-        self.startdt = start
-        self.enddt = end
-        # TODO cleanup
-        self.startdate = self.startdt.strftime(self.conf.default.longdateformat)
-        self.starttime = self.startdt.strftime(self.conf.default.timeformat)
-        self.enddate = self.enddt.strftime(self.conf.default.longdateformat)
-        self.endtime = self.enddt.strftime(self.conf.default.timeformat)
-        self.startdate_bg = 'edit'
-        self.starttime_bg = 'edit'
-        self.enddate_bg = 'edit'
-        self.endtime_bg = 'edit'
-        self.startdatewidget = None
-        self.starttimewidget = None
-        self.enddatewidget = None
-        self.endtimewidget = None
-        self.allday = False
-        if not isinstance(start, datetime):
-            self.allday = True
-
-        self.checkallday = urwid.CheckBox('Allday', state=self.allday,
-                                          on_state_change=self.toggle)
-        self.toggle(None, self.allday)
-
-    def toggle(self, checkbox, state):
-        """change from allday to datetime event
-
-        :param checkbox: the checkbox instance that is used for toggling, gets
-                         automatically passed by urwid (is not used)
-        :type checkbox: checkbox
-        :param state: True if allday event, False if datetime
-        :type state: bool
-        """
-        self.allday = state
-        datewidth = len(self.startdate) + 7
-
-        edit = urwid.Edit(caption=('', 'From: '), edit_text=self.startdate, wrap='any')
-        edit = urwid.AttrMap(edit, self.startdate_bg, 'editcp', )
-        edit = urwid.Padding(edit, align='left', width=datewidth, left=0, right=1)
-        self.startdatewidget = edit
-
-        edit = urwid.Edit(caption=('', 'To:   '), edit_text=self.enddate, wrap='any')
-        edit = urwid.AttrMap(edit, self.enddate_bg, 'editcp', )
-        edit = urwid.Padding(edit, align='left', width=datewidth, left=0, right=1)
-        self.enddatewidget = edit
-        if state is True:
-            timewidth = 1
-            self.starttimewidget = urwid.Text('')
-            self.endtimewidget = urwid.Text('')
-        elif state is False:
-            timewidth = len(self.starttime) + 1
-            edit = urwid.Edit(edit_text=self.starttime, wrap='any')
-            edit = urwid.AttrMap(edit, self.starttime_bg, 'editcp', )
-            edit = urwid.Padding(edit, align='left', width=len(self.starttime) + 1, left=1)
-            self.starttimewidget = edit
-
-            edit = urwid.Edit(edit_text=self.endtime, wrap='any')
-            edit = urwid.AttrMap(edit, self.endtime_bg, 'editcp', )
-            edit = urwid.Padding(edit, align='left', width=len(self.endtime) + 1, left=1)
-            self.endtimewidget = edit
-
-        columns = CPile([
-            CColumns([(datewidth, self.startdatewidget), (timewidth, self.starttimewidget)], dividechars=1),
-            CColumns([(datewidth, self.enddatewidget), (timewidth, self.endtimewidget)], dividechars=1),
-            self.checkallday], focus_item=2)
-        urwid.WidgetWrap.__init__(self, columns)
-
-    @property
-    def changed(self):
-        """
-        returns True if content has been edited, False otherwise
-        """
-        return ((self.startdt != self.newstart) or
-                (self.enddt != self.newend))
-
-    @property
-    def newstart(self):
-        newstartdatetime = self._newstartdate
-        if not self.checkallday.state:
-            if not hasattr(self.startdt, 'tzinfo') or self.startdt.tzinfo is None:
-                tzinfo = self.conf.default.default_timezone
-            else:
-                tzinfo = self.startdt.tzinfo
-            try:
-                newstarttime = self._newstarttime
-                newstartdatetime = datetime.combine(newstartdatetime, newstarttime)
-                newstartdatetime = tzinfo.localize(newstartdatetime)
-            except TypeError:
-                return None
-        return newstartdatetime
-
-    @property
-    def _newstartdate(self):
-        try:
-            self.startdate = self.startdatewidget.original_widget.original_widget.get_edit_text()
-            newstartdate = datetime.strptime(
-                self.startdate,
-                self.conf.default.longdateformat).date()
-            self.startdate_bg = 'edit'
-            return newstartdate
-        except ValueError:
-            self.startdate_bg = 'alert'
-            return None
-
-    @property
-    def _newstarttime(self):
-        try:
-            self.starttime = self.starttimewidget.original_widget.original_widget.get_edit_text()
-            newstarttime = datetime.strptime(
-                self.starttime,
-                self.conf.default.timeformat).time()
-            self.starttime_bg = 'edit'
-            return newstarttime
-        except ValueError:
-            self.starttime_bg = 'alert'
-            return None
-
-    @property
-    def newend(self):
-        newenddatetime = self._newenddate
-        if not self.checkallday.state:
-            if not hasattr(self.enddt, 'tzinfo') or self.enddt.tzinfo is None:
-                tzinfo = self.conf.default.default_timezone
-            else:
-                tzinfo = self.enddt.tzinfo
-            try:
-                newendtime = self._newendtime
-                newenddatetime = datetime.combine(newenddatetime, newendtime)
-                newenddatetime = tzinfo.localize(newenddatetime)
-            except TypeError:
-                return None
-        return newenddatetime
-
-    @property
-    def _newenddate(self):
-        try:
-            self.enddate = self.enddatewidget.original_widget.original_widget.get_edit_text()
-            newenddate = datetime.strptime(
-                self.enddate,
-                self.conf.default.longdateformat).date()
-            self.enddate_bg = 'edit'
-            return newenddate
-        except ValueError:
-            self.enddate_bg = 'alert'
-            return None
-
-    @property
-    def _newendtime(self):
-        try:
-            self.endtime = self.endtimewidget.original_widget.original_widget.get_edit_text()
-            newendtime = datetime.strptime(
-                self.endtime,
-                self.conf.default.timeformat).time()
-            self.endtime_bg = 'edit'
-            return newendtime
-        except ValueError:
-            self.endtime_bg = 'alert'
-            return None
-
-
 class EventViewer(urwid.WidgetWrap):
+
     """
     Base Class for EventEditor and EventDisplay
     """
+
     def __init__(self, conf, collection):
         self.conf = conf
         self.collection = collection
@@ -689,10 +546,12 @@ class EventViewer(urwid.WidgetWrap):
 
 
 class EventDisplay(EventViewer):
+
     """showing events
 
     widget for displaying one event's details
     """
+
     def __init__(self, conf, event, collection=None):
         super(EventDisplay, self).__init__(conf, collection)
         lines = []
@@ -700,23 +559,24 @@ class EventDisplay(EventViewer):
 
         # start and end time/date
         if event.allday:
-            startstr = event.start.strftime(self.conf.default.dateformat)
-            if event.start == event.end:
+            startstr = event.start.strftime(self.conf.locale.dateformat)
+            end = event.end - timedelta(days=1)
+            if event.start == end:
                 lines.append(urwid.Text('On: ' + startstr))
             else:
-                endstr = event.end.strftime(self.conf.default.dateformat)
+                endstr = end.strftime(self.conf.locale.dateformat)
                 lines.append(
                     urwid.Text('From: ' + startstr + ' to: ' + endstr))
 
         else:
-            startstr = event.start.strftime(self.conf.default.dateformat +
-                                            ' ' + self.conf.default.timeformat)
+            startstr = event.start.strftime(self.conf.locale.dateformat +
+                                            ' ' + self.conf.locale.timeformat)
             if event.start.date == event.end.date:
-                endstr = event.end.strftime(self.conf.default.timeformat)
+                endstr = event.end.strftime(self.conf.locale.timeformat)
             else:
-                endstr = event.end.strftime(self.conf.default.dateformat +
+                endstr = event.end.strftime(self.conf.locale.dateformat +
                                             ' ' +
-                                            self.conf.default.timeformat)
+                                            self.conf.locale.timeformat)
                 lines.append(urwid.Text('From: ' + startstr +
                                         ' To: ' + endstr))
 
@@ -736,9 +596,11 @@ class EventDisplay(EventViewer):
 
 
 class EventEditor(EventViewer):
+
     """
     Widget for event Editing
     """
+
     def __init__(self, conf, event, collection=None, cancel=None):
         """
         :type event: khal.event.Event
@@ -757,7 +619,12 @@ class EventEditor(EventViewer):
         except KeyError:
             self.location = u''
 
-        self.startendeditor = StartEndEditor(event.start, event.end, self.conf)
+        if event.allday:
+            end = event.end - timedelta(days=1)
+        else:
+            end = event.end
+
+        self.startendeditor = StartEndEditor(event.start, end, self.conf)
         try:
             rrule = self.event.vevent['RRULE']
         except KeyError:
@@ -766,7 +633,7 @@ class EventEditor(EventViewer):
         self.summary = urwid.Edit(
             edit_text=event.vevent['SUMMARY'])
         self.accountchooser = AccountChooser(self.event.account,
-                                             self.conf.sync.accounts)
+                                             self.collection.names)
         accounts = CColumns([(9, urwid.Text(u'Calendar: ')),
                              self.accountchooser])
         self.description = urwid.Edit(caption=u'Description: ',
@@ -793,26 +660,20 @@ class EventEditor(EventViewer):
 
     @property
     def changed(self):
-        # TODO refactor
-        changed = False
         if self.summary.get_edit_text() != self.event.vevent['SUMMARY']:
-            changed = True
+            return True
 
-        key = 'DESCRIPTION'
-        if ((key in self.event.vevent and self.description.get_edit_text() != self.event.vevent[key]) or
-                self.description.get_edit_text() != ''):
-            changed = True
+        if self.description.get_edit_text() != \
+                self.event.vevent.get('DESCRIPTION', ''):
+            return True
 
-        key = 'LOCATION'
-        if ((key in self.event.vevent and self.description.get_edit_text() != self.event.vevent[key]) or
-                self.location.get_edit_text() != ''):
-            changed = True
+        if self.location.get_edit_text() != \
+                self.event.vevent.get('LOCATION', ''):
+            return True
 
-        if self.startendeditor.changed:
-            changed = True
-        if self.accountchooser.changed:
-            changed = True
-        return changed
+        if self.startendeditor.changed or self.accountchooser.changed:
+            return True
+        return False
 
     def update(self):
         changed = False
@@ -820,9 +681,11 @@ class EventEditor(EventViewer):
             self.event.vevent['SUMMARY'] = self.summary.get_edit_text()
             changed = True
 
-        for key, prop in [('DESCRIPTION', self.description), ('LOCATION', self.location)]:
-            if ((key in self.event.vevent and prop.get_edit_text() != self.event.vevent[key]) or
-                    prop.get_edit_text() != ''):
+        for key, prop in [
+            ('DESCRIPTION', self.description),
+            ('LOCATION', self.location)
+        ]:
+            if prop.get_edit_text() != self.event.vevent.get(key, ''):
                 self.event.vevent[key] = prop.get_edit_text()
                 changed = True
 
@@ -832,12 +695,16 @@ class EventEditor(EventViewer):
             # (timezone was missing after to_ical() )
             self.event.vevent.pop('DTSTART')
             self.event.vevent.add('DTSTART', self.startendeditor.newstart)
+            if self.event.allday:
+                end = self.startendeditor.newend + timedelta(days=1)
+            else:
+                end = self.startendeditor.newend
             try:
                 self.event.vevent.pop('DTEND')
-                self.event.vevent.add('DTEND', self.startendeditor.newend)
+                self.event.vevent.add('DTEND', end)
             except KeyError:
                 self.event.vevent.pop('DURATION')
-                duration = (self.startendeditor.newend -
+                duration = (end -
                             self.startendeditor.newstart)
                 self.event.vevent.add('DURATION', duration)
 
@@ -852,22 +719,27 @@ class EventEditor(EventViewer):
         saves the event to the db (only when it has been changed)
         :param button: not needed, passed via the button press
         """
-        changed = self.changed  # need to call this to set date backgrounds to False
+        # need to call this to set date backgrounds to False
+        changed = self.changed
         self.update()
-        if 'alert' in [self.startendeditor.startdate_bg,
-                       self.startendeditor.starttime_bg,
-                       self.startendeditor.enddate_bg,
-                       self.startendeditor.endtime_bg]:
-            self.startendeditor.toggle(None, state=self.startendeditor.allday)
+        if 'alert' in [self.startendeditor.bgs.startdate,
+                       self.startendeditor.bgs.starttime,
+                       self.startendeditor.bgs.enddate,
+                       self.startendeditor.bgs.endtime]:
+            self.startendeditor.refresh(None, state=self.startendeditor.allday)
             self.pile.set_focus(1)  # the startendeditor
             return
+
         if changed is True:
             try:
                 self.event.vevent['SEQUENCE'] += 1
             except KeyError:
                 self.event.vevent['SEQUENCE'] = 0
 
-            if self.event.status == NEWNOTSAVED:
+            self.event.allday = self.startendeditor.allday
+            if self.event.etag is None:  # has not been saved before
+                # TODO look for better way to detect this
+                self.event.account = self.accountchooser.account
                 self.collection.new(self.event)
             elif self.accountchooser.changed:
                 self.collection.change_collection(self.event,
@@ -892,20 +764,27 @@ class EventEditor(EventViewer):
 
 
 class ClassicView(Pane):
+
     """default Pane for khal
 
     showing a CalendarWalker on the left and the eventList + eventviewer/editor
     on the right
     """
+
     def __init__(self, collection, conf=None, title=u'',
                  description=u''):
         self.collection = collection
-        self.eventscolumn = EventColumn(conf=conf, collection=collection)
-        weeks = calendar_walker(view=self, firstweekday=conf.default.firstweekday)
+        self.deleted = []
+        self.eventscolumn = EventColumn(conf=conf,
+                                        collection=collection,
+                                        deleted=self.deleted)
+        weeks = calendar_walker(
+            view=self, firstweekday=conf.locale.firstweekday)
         events = self.eventscolumn
         columns = CColumns([(25, weeks), events],
-                           dividechars=2, box_columns=[0, 1])
-        self.eventscolumn.update(date.today())  # showing with today's events
+                           dividechars=2,
+                           box_columns=[0, 1])
+        self.eventscolumn.update(date.today())  # starting with today's events
         Pane.__init__(self, columns, title=title, description=description)
 
     def get_keys(self):
@@ -920,12 +799,19 @@ class ClassicView(Pane):
     def new_event(self, date):
         self.eventscolumn.new(date)
 
+    def cleanup(self, data):
+        for part in self.deleted:
+            account, uid = part.split('\n', 1)
+            event = self.collection.get_event(uid, account)
+            self.collection.delete(event)
+        pass
 
-def start_pane(pane, header=''):
+
+def start_pane(pane, callback, header=''):
     """Open the user interface with the given initial pane."""
     frame = Window(header=header,
                    footer='arrows: navigate, enter: select, q: quit, ?: help')
-    frame.open(pane)
+    frame.open(pane, callback)
     loop = urwid.MainLoop(frame, Window.PALETTE,
                           unhandled_input=frame.on_key_press,
                           pop_ups=True)
